==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ga-IE/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Sócmhainní a shanntar do: ainm',
    'bulk_update_warn'	=> 'Tá tú ar tí in eagar na hairíonna seo a leanas: úsáideoirí user_count. Tabhair faoi deara nach féidir leat tréithe úsáideora féin a athrú ag baint úsáide as an bhfoirm seo, agus ní mór duit athruithe a dhéanamh chuig d\'úsáideoir féin ina n-aonar.',
    'bulk_update_help'	=> 'Ceadaíonn an fhoirm seo duit il-úsáideoirí a thabhairt cothrom le dáta ag an am céanna. Líon isteach na réimsí is gá duit a athrú ach amháin. Ní dhéanfar aon réimsí fágtha gan athrú.',
    'current_assets'    => 'Seiceáil na sócmhainní faoi láthair don úsáideoir seo',
    'clone'             => 'Úsáideoir Clón',
    'contact_user'      => 'Ainm an Teagmhálaí',
    'edit'              => 'Athraigh Úsáideoir',
    'filetype_info'     => 'Is iad píopaí comhaid a cheadaítear png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Stair le haghaidh: ainm',
	'info'				=> 'Eolas',
    'restore_user'		=> 'Cliceáil anseo chun iad a athchóiriú.',
    'last_login'        => 'Logáil isteach deireanach',
    'ldap_config_text'  => 'Is féidir suímh chumraíochta LDAP a fháil Admin> Settings. Socrófar an suíomh roghnaithe (roghnach) do gach úsáideoir a allmhairítear.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Bogearraí Seiceáil amach chuig: ainm',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Féach Úsáideoir: ainm',
    'usercsv'           => 'Comhad CSV',
    'two_factor_admin_optin_help' => 'Ceadaíonn do shuímh riaracháin reatha forfheidhmiú roghnach fíordheimhnithe dhá fhachtóir.',
    'two_factor_enrolled' => 'Gléas 2FA Cláraithe',
    'two_factor_active'   => '2FA Gníomhach',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ga-IE/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'This user can login',
    'activated_disabled_help_text' => 'You cannot edit activation status for your own account.',
    'assets_user'       => 'Sócmhainní a shanntar do: ainm',
    'bulk_update_warn'	=> 'Tá tú ar tí in eagar na hairíonna seo a leanas: úsáideoirí user_count. Tabhair faoi deara nach féidir leat tréithe úsáideora féin a athrú ag baint úsáide as an bhfoirm seo, agus ní mór duit athruithe a dhéanamh chuig d\'úsáideoir féin ina n-aonar.',
    'bulk_update_help'	=> 'Ceadaíonn an fhoirm seo duit il-úsáideoirí a thabhairt cothrom le dáta ag an am céanna. Líon isteach na réimsí is gá duit a athrú ach amháin. Ní dhéanfar aon réimsí fágtha gan athrú.',
    'current_assets'    => 'Seiceáil na sócmhainní faoi láthair don úsáideoir seo',
    'clone'             => 'Úsáideoir Clón',
    'contact_user'      => 'Ainm an Teagmhálaí',
    'edit'              => 'Athraigh Úsáideoir',
    'filetype_info'     => 'Is iad píopaí comhaid a cheadaítear png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Stair le haghaidh: ainm',
    'info'				=> 'Eolas',
    'restore_user'		=> 'Cliceáil anseo chun iad a athchóiriú.',
    'last_login'        => 'Logáil isteach deireanach',
    'ldap_config_text'  => 'Is féidir suímh chumraíochta LDAP a fháil Admin> Settings. Socrófar an suíomh roghnaithe (roghnach) do gach úsáideoir a allmhairítear.',
    'print_assigned'    => 'Print All Assigned',
    'software_user'     => 'Bogearraí Seiceáil amach chuig: ainm',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Féach Úsáideoir: ainm',
    'usercsv'           => 'Comhad CSV',
    'two_factor_admin_optin_help' => 'Ceadaíonn do shuímh riaracháin reatha forfheidhmiú roghnach fíordheimhnithe dhá fhachtóir.',
    'two_factor_enrolled' => 'Gléas 2FA Cláraithe',
    'two_factor_active'   => '2FA Gníomhach',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
